@@ -1,4 +1,4 @@
 def sign(x: int) -> int:
-    if x:
+    if x != 0:
         return 1 if x > 0 else -1
     return 0
